#!/bin/sh
# the next line restarts using wish \
exec wish "$0" "$@"

#    Copyright 2003 Regis Damongeot

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#window title
wm title . "TkDVD 3.4"
wm geometry . 700x520
wm protocol . WM_DELETE_WINDOW { save_options; destroy . }
set burn_type "burn_dvd"
set v_create_iso "no"
set burning_device "/dev/sr0"
set burn_command "growisofs"
set volume_id ""
set volume_id_o ""
set option_udf_ext ""
set option_joliet_ext "-J"
set option_rr_ext ""
set option_rra_ext "-r"
set option_pad "-pad"
set file_list ""
set excluded_file_list ""
set only_one_file ""
set input ""
set total_file_size_f "0 KB"
set space_left_f "4.377 GB"
set dvd_size "4589850"
set selected_directory "[pwd]"
set iso_file ""
set t_session "-use-the-force-luke=tty -Z"
set option_dvd_compat "-dvd-compat"
set option_overburn ""
set command_line "growisofs $t_session $burning_device $option_joliet_ext $option_rr_ext $option_rra_ext $option_dvd_compat $option_pad -graft-points"
#needed to not have too large precision when show total files size
set tcl_precision 4

#set fullpath to source scripts (if TkDVD not launch from it install direcotory)
set source_directory "[info script]"
if { [file pathtype $source_directory] == "absolute" } {
	set source_directory [file dirname $source_directory]
} else {
	set source_directory "[file dirname [pwd]/[info script]]"
}

#source save/load config options procedure
 #    Copyright 2003 Regis Damongeot

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

set current_version "3.2"

proc save_options {} {
	global current_version dvd_size env burning_device
	#puts "saving ver $current_version and dvdsize $dvd_size"
	check_config_file_exist
	set config_file [open $env(HOME)/.tkdvd/config w]
	puts $config_file "version = $current_version"
	puts $config_file "dvd_size = $dvd_size"
	#when "create iso image" is selected, burning_device is equal to the path of the image and so it should not be saved
	if {![string compare -length 3 $burning_device "/dev"]} {
		puts $config_file "burning_device = $burning_device"
	} else {
		puts $config_file "burning_device = /dev/sr0"
	}
	close $config_file
}

proc load_options {} {
	global env current_version space_left_f dvd_size burning_device
	set config_version ""
	set string_temp ""
	check_config_file_exist
	set config_file [open $env(HOME)/.tkdvd/config r]
	while { ! [eof $config_file] } {
		gets $config_file string_temp
		if { [lindex $string_temp 0] == "version" } {
			if {[lindex $string_temp end] == $current_version } {
				set config_version $current_version
			} else {
				update_version_config_file [lindex $string_temp end]
				set config_version [lindex $string_temp end]
			}
		}
		if {[lindex $string_temp 0] == "dvd_size"} {
			set dvd_size [lindex $string_temp end]
		}
		if {[lindex $string_temp 0] == "burning_device"} {
			set burning_device [lindex $string_temp end]
		}
	}
	if { [eof $config_file] && (($dvd_size != "4589850") || ($dvd_size != "8300790")) } {
		#puts "cant find dvd_size variable in config file, setting to default"
		set dvd_size "4589850"
	}
	#puts "found tkdvd config ver $config_version and dvdsize $dvd_size"
	if {$dvd_size == "8300790"} {
		#default set to 4.7Go when building main window
		set space_left_f "7.916 Go"
	}
	close $config_file
}

proc check_config_file_exist {} {
	global env current_version
	if { ! [file exists "$env(HOME)/.tkdvd/config"] } {
		if { ! [file isdirectory "$env(HOME)/.tkdvd"] } {
			#puts "creating ~/.tkdvd"
			exec mkdir $env(HOME)/.tkdvd
		}
		if { ! [file exists "$env(HOME)/.tkdvd/config"] } {
			#puts "tkdvd config file doesnt exist, creating it"
			exec touch $env(HOME)/.tkdvd/config
		}
		save_options
		#set config_file [open $env(HOME)/.tkdvd/config w]
		#puts $config_file "version = $current_version"
		#puts $config_file "dvd_size = 4589850"
		#close $config_file
	}
}

proc update_version_config_file { old_version } {
	global current_version env dvd_size
	puts "updating config file from $old_version to $current_version"
	#for updating, just load previous version options and call save_options proc
	if { $old_version == "2.8" } {
		set config_file [open $env(HOME)/.tkdvd/config r]
		set string_temp ""
		while {! [eof $config_file]} {
			gets $config_file string_temp
			puts "$string_temp"
			if {[lindex $string_temp 0] == "dvd_size"} {
				set dvd_size [lindex $string_temp end]
			}
		}
		close $config_file
		save_options
	}
}
#source of the total file size count procedure
#    Copyright 2003 Regis Damongeot

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 
proc refresh_total_file_size {} {
	global file_list total_file_size_f space_left_f command_line t_session excluded_file_list dvd_size
	#set local var total_file_size_type cause if total_file_size < 1024 octets, total_file_size isnt set
	set total_file_size_type "KB"
	#set local var total_file_size cause if llength $file_list > 1 then $total_file_size is not set for the fisrt iteration of "for"
	set total_file_size 0
	#attention: $total_file_size is in Ko to prevent overflow if $total_file_size > 2go
	if {[llength $file_list] == 0} {
		set total_file_size 0
	} elseif { [llength $file_list] == 1 } {
		if {[file isdirectory [lindex $file_list 0]]} {
			set total_file_size [expr [lindex [exec du -ks -- [lindex $file_list 0]] 0] - [file size [lindex $file_list 0]]/1024]
		} else { set total_file_size [expr [file size [lindex $file_list 0]]/1024.] }
	} else {
		for { set i 0 } {$i < [llength $file_list]} {incr i} {
			if {[file isdirectory [lindex $file_list $i]]} {
				set total_file_size [expr $total_file_size + [expr [lindex [exec du -ks -- [lindex $file_list $i]] 0] - [file size [lindex $file_list 0]]/1024]]
			} else { set total_file_size [expr ($total_file_size + [expr ([file size [lindex $file_list $i]])/1024.])] }
		}
	}
	
	
	foreach i $excluded_file_list {
		if { [file isdirectory $i] } {
			set total_file_size [expr $total_file_size - [exec du -ks $i | cut -f1 ] ]
		} elseif { [file isfile $i] } {
			set total_file_size [expr $total_file_size - ([ file size $i ] / 1024.) ]
		}
	}
	
	
	# save total_file_size in order to reuse it to calculate space_left more easily
	set space_left $total_file_size
	if { $total_file_size > 1048576 } {
		set total_file_size [expr (($total_file_size)/1024.)/1024.]
		set total_file_size_type "GB"
	} elseif { $total_file_size > 1024 } {
		set total_file_size [expr ($total_file_size)/1024.]
		set total_file_size_type "MB"
	} else {
		set total_file_size $total_file_size
		set total_file_size_type "KB"
	}
	set total_file_size_f "$total_file_size $total_file_size_type"
	switch $total_file_size_type  {
		GB {
			set space_left [expr ($dvd_size - $space_left)/1024.]
			set space_left_type "MB"
		}
		MB {
			set space_left [expr (($dvd_size - $space_left)/1024.)/1024.]
			set space_left_type "GB"
		}
		KB {
			set space_left [expr (($dvd_size - $space_left)/1024.)/1024.]
			set space_left_type "GB"
		}
	}
	#if {$t_session == "-use-the-force-luke=tty -Z"} {set space_left_f "$space_left $space_left_type"
	#} else {set space_left_f "N/A"}
	set space_left_f "$space_left $space_left_type"
}
#source of the refresh command line procedure (main procedure)
#    Copyright 2003 Regis Damongeot

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 
proc refresh_cmd_line {} {
	global total_file_size_f option_udf_ext option_joliet_ext option_rr_ext option_rra_ext file_list volume_id option_pad burn_type command_line t_session burning_device iso_file space_left_f burn_command option_dvd_compat option_overburn excluded_file_list dvd_size v_create_iso
	if { [catch { exec ps -A | grep growisofs }] != 0 } {
		if { ($burn_type == "burn_dvd") || ($burn_type == "create_iso") } {
			check_volume_id
			if { "$option_rr_ext" == "-R" && "$option_rra_ext" == "-r" } {
				set command_line "You cant set Anonymous RR ext and normal RR ext"
				#deactivate burn button to prevent errors
				.f_burn.go_button configure -state disabled
			} elseif { (([lindex $space_left_f 0] <0 ) || ([lindex $total_file_size_f 0] > 4.377 && $dvd_size == 4589850)) && [lindex $total_file_size_f 1] == "GB" && $option_overburn == "" && $burn_type == "burn_dvd" && $v_create_iso == "no" } {
				#exact maximum size: 4.37721610069. Although it should be oversized because "du" return > real file size due to indirect blocks its undersized to prevent disallowing burning when beleving overburn is needed while its no the case (anyway growisofs check it)
				set command_line "You need to enable overburning if you want to burn all theses files"
				.f_burn.go_button configure -state disabled
			} else {
				#create list containing excluded files and directories prefixed with -m option
				set excluded_file_list_t ""
				foreach i $excluded_file_list {
					append excluded_file_list_t "-m {$i} "
					
				} 
				#if we burn a DVD-Video UDF complient we need to not modify directory with graft points
				if {$option_udf_ext != "-dvd-video" } {
					set command_line "[concat $burn_command $t_session $burning_device $volume_id $option_udf_ext $option_joliet_ext $option_rr_ext $option_rra_ext $option_dvd_compat $option_overburn $option_pad -graft-points $excluded_file_list_t [file_list_w_modif_dir $file_list]]"
				} else {
					set command_line "[concat $burn_command $t_session $burning_device $volume_id $option_udf_ext $option_dvd_compat $option_overburn $excluded_file_list_t $file_list]"
				}
				#reactive le bouton burn si tt est ok
				if { [.f_burn.go_button cget -state] == "disabled" } { .f_burn.go_button configure -state normal }
			}
		} elseif { $burn_type == "burn_iso" } {
			set command_line "$burn_command $t_session $option_dvd_compat $option_overburn $burning_device=$iso_file"
			if { [.f_burn.go_button cget -state] == "disabled" } { .f_burn.go_button configure -state normal }
		}
	} else { set command_line "growisofs is currently working" }
	if {($t_session == "-M" && $space_left_f != "N/A") || ($t_session == "-use-the-force-luke=tty -Z" && $space_left_f == "N/A") } { refresh_total_file_size }
	return 1
}
#source of excluded file window and its needed procedures
#    Copyright 2003 Regis Damongeot

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

proc proc_add_excluded_f_d { files_list } {
	global excluded_file_list
	#if user click on cancel, returned list = ""
	if { $files_list != "" } {
		#foreach needed for multiple files selection
		foreach i $files_list {
			lappend excluded_file_list $i
		}
		#puts "$excluded_file_list"
		refresh_total_file_size
		refresh_cmd_line
	} else {
	#puts "No file or dir chosen"
	}
}

proc delete_excleded_files {} {
	global excluded_file_list
	if { "[.excluded_file_window.file_list.list curselection]" == "" } {
	} else {
		set excluded_file_list [lreplace $excluded_file_list [.excluded_file_window.file_list.list curselection] [.excluded_file_window.file_list.list curselection]]
		#refresh command line entry after checking space used to check overburn condition
		refresh_total_file_size
		refresh_cmd_line
	}
}

proc excluded_file_window {} {
	global excluded_file_list
if { ! [winfo exists .excluded_file_window] } {
	toplevel .excluded_file_window -highlightthickness 1 -highlightcolor blue -background #f5f5f5
	wm title .excluded_file_window "Excluded Files And Directories"
	frame .excluded_file_window.f_buttons
	button .excluded_file_window.f_buttons.b_add_files -highlightbackground red -width 7 -text "Add Files..." -command { proc_add_excluded_f_d [tk_getOpenFile -multiple 1] }
	button .excluded_file_window.f_buttons.b_add_dir -highlightbackground red -width 15 -text "Add Directory..." -command { proc_add_excluded_f_d [tk_chooseDirectory -mustexist true] }
	button .excluded_file_window.f_buttons.b_del -highlightbackground red -width 15 -text "Delete From List" -command { delete_excleded_files }
	button .excluded_file_window.f_buttons.b_clear -highlightbackground red -width 7 -text "Clear List" -command { set excluded_file_list ""; refresh_total_file_size; refresh_cmd_line }
	button .excluded_file_window.f_buttons.b_close -highlightbackground red -width 7 -text "Close" -command {destroy .excluded_file_window}
	pack .excluded_file_window.f_buttons.b_add_files .excluded_file_window.f_buttons.b_add_dir .excluded_file_window.f_buttons.b_del .excluded_file_window.f_buttons.b_clear .excluded_file_window.f_buttons.b_close -side left
	pack .excluded_file_window.f_buttons -side top
	
	frame .excluded_file_window.file_list
	listbox .excluded_file_window.file_list.list -bg #f5f5f5 -listvariable excluded_file_list -heigh 15 -yscrollcommand { .excluded_file_window.file_list.scroll_bar set }
	scrollbar .excluded_file_window.file_list.scroll_bar -command { .file_list.list yview }
	pack .excluded_file_window.file_list.scroll_bar -side right -fill y
	pack .excluded_file_window.file_list.list -fill x
	pack .excluded_file_window.file_list -fill both -expand false -side bottom
}
}

#source advanced options window procedure
#    Copyright 2003 Regis Damongeot

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

proc advanced_options_window {} {
	global burn_type v_create_iso dvd_size
if { ! [winfo exists .advanced_options_window] } {
	toplevel .advanced_options_window -highlightthickness 1 -highlightcolor blue -background #f5f5f5
	wm title .advanced_options_window "Advanced Options"
	
	#create frame for options buttons
	frame .advanced_options_window.f_fs_ext -background #f5f5f5
	frame .advanced_options_window.options_fs -background #f5f5f5
	frame .advanced_options_window.f_options_udf -background #f5f5f5
	frame .advanced_options_window.udf_radiobuttons -background #f5f5f5
	frame .advanced_options_window.f_opts_dvd_size -background #f5f5f5
	frame .advanced_options_window.f_dvd_size -background #f5f5f5
	frame .advanced_options_window.f_oth_opts -background #f5f5f5
	frame .advanced_options_window.options_oth -background #f5f5f5
	
	label .advanced_options_window.f_fs_ext.label_fs_ext -bg #f5f5f5 -text "Filesystem extensions:"
	label .advanced_options_window.f_options_udf.label_fs_udf -bg #f5f5f5 -text "UDF extensions:"
	label .advanced_options_window.f_opts_dvd_size.label_dvd_size -bg #f5f5f5 -text "DVD Size:"
	label .advanced_options_window.f_oth_opts.label_oth_opts -bg #f5f5f5 -text "Other options:"
	
	
	checkbutton .advanced_options_window.options_fs.joliet_ext -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "Add Joliet extensions (-J)" -variable option_joliet_ext -offvalue "" -onvalue "-J" -command refresh_cmd_line
	
	checkbutton .advanced_options_window.options_fs.rr_ext -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "Add Rock Ridge extensions (-R)" -variable option_rr_ext -offvalue "" -onvalue "-R"  -command refresh_cmd_line
	
	checkbutton .advanced_options_window.options_oth.pad -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "Pad (highly recommanded) (-pad)" -variable option_pad -offvalue "" -onvalue "-pad"  -command refresh_cmd_line
	
	checkbutton .advanced_options_window.options_fs.rra_ext -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "Add anonymous Rock Ridge extensions (all files set to r--r--r-- or +x if executable) (-r)" -variable option_rra_ext -offvalue "" -onvalue "-r" -command refresh_cmd_line
	
	radiobutton .advanced_options_window.udf_radiobuttons.udf_ext_off -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "Off" -variable option_udf_ext -value "" -command refresh_cmd_line
	
	radiobutton .advanced_options_window.udf_radiobuttons.udf_ext -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "UDF extensions (-udf)" -variable option_udf_ext -value "-udf" -command refresh_cmd_line
	
	radiobutton .advanced_options_window.udf_radiobuttons.dvd_video_ext -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "DVD Video compliant UDF file system (-dvd-video)" -variable option_udf_ext -value "-dvd-video" -command refresh_cmd_line
	
	checkbutton .advanced_options_window.options_oth.overburn -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "Overburn (-overburn)" -variable option_overburn -offvalue "" -onvalue "-overburn" -command refresh_cmd_line
	
	checkbutton .advanced_options_window.options_oth.multisession -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "Add session to disc (-M)" -variable t_session -offvalue "-use-the-force-luke=tty -Z" -onvalue "-M"  -command refresh_cmd_line
	
	checkbutton .advanced_options_window.options_oth.monosession -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "Maximum media compatibility (if DVD R => create single session closed disc) (-dvd-compat)" -variable option_dvd_compat -offvalue "" -onvalue "-dvd-compat"  -command refresh_cmd_line
	
	
	radiobutton .advanced_options_window.f_dvd_size.single_layer  -activebackground #f5f5f5 -background #f5f5f5 -highlightbackground #f5f5f5 -command { refresh_total_file_size; refresh_cmd_line } -text "4.7 Go" -variable dvd_size -value 4589850
	
	radiobutton .advanced_options_window.f_dvd_size.dual_layer  -activebackground #f5f5f5 -background #f5f5f5 -highlightbackground #f5f5f5 -command { refresh_total_file_size; refresh_cmd_line }  -text "8.5 Go (DL)" -variable dvd_size -value 8300790
	
	
	#button .advanced_options_window.f_dvd_size.b_save -highlightbackground red -text "Save" -command { save_options }
	
	button .advanced_options_window.b_close -highlightbackground red -text "Close" -command { destroy .advanced_options_window }
	
	if { $burn_type == "burn_dvd" &&  $v_create_iso == "no" } {
		.advanced_options_window.options_oth.pad configure -state normal
		.advanced_options_window.udf_radiobuttons.udf_ext configure -state normal
		.advanced_options_window.udf_radiobuttons.dvd_video_ext configure -state normal
		.advanced_options_window.udf_radiobuttons.udf_ext_off configure -state normal
		.advanced_options_window.options_fs.rra_ext configure -state normal
		.advanced_options_window.options_fs.rr_ext configure -state normal
		.advanced_options_window.options_fs.joliet_ext configure -state normal
		.advanced_options_window.options_oth.overburn configure -state normal
		.advanced_options_window.options_oth.multisession configure -state normal
		.advanced_options_window.options_oth.monosession configure -state normal
		#.advanced_options_window.f_dvd_size.single_layer configure -state normal
		#.advanced_options_window.f_dvd_size.dual_layer configure -state normal
		#.advanced_options_window.f_dvd_size.b_save configure -state normal
	} elseif { $burn_type == "burn_dvd" && $v_create_iso == "yes" } {
		.advanced_options_window.options_oth.pad configure -state normal
		.advanced_options_window.udf_radiobuttons.udf_ext configure -state normal
		.advanced_options_window.udf_radiobuttons.udf_ext_off configure -state normal
		.advanced_options_window.udf_radiobuttons.dvd_video_ext configure -state normal
		.advanced_options_window.options_fs.rr_ext configure -state normal
		.advanced_options_window.options_fs.joliet_ext configure -state normal
		.advanced_options_window.options_fs.rra_ext configure -state normal
		.advanced_options_window.options_oth.overburn configure -state disable
		.advanced_options_window.options_oth.multisession configure -state disabled
		.advanced_options_window.options_oth.monosession configure -state disabled
		#.advanced_options_window.f_dvd_size.single_layer configure -state disabled
		#.advanced_options_window.f_dvd_size.dual_layer configure -state disabled
		#.advanced_options_window.f_dvd_size.b_save configure -state disabled
	} elseif { $burn_type == "burn_iso" } {
		#.advanced_options_window.f_dvd_size.single_layer configure -state normal
		#.advanced_options_window.f_dvd_size.dual_layer configure -state normal
		#.advanced_options_window.f_dvd_size.b_save configure -state normal
		.advanced_options_window.options_oth.pad configure -state disabled
		.advanced_options_window.udf_radiobuttons.udf_ext configure -state disabled
		.advanced_options_window.udf_radiobuttons.udf_ext_off configure -state disabled
		.advanced_options_window.udf_radiobuttons.dvd_video_ext configure -state disabled
		.advanced_options_window.options_fs.rra_ext configure -state disabled
		.advanced_options_window.options_fs.rr_ext configure -state disabled
		.advanced_options_window.options_fs.joliet_ext configure -state disabled
		.advanced_options_window.options_oth.overburn configure -state normal
		.advanced_options_window.options_oth.multisession configure -state normal
		.advanced_options_window.options_oth.monosession configure -state disabled
	}
	
	
	#pack buttons and labels
	pack .advanced_options_window.f_fs_ext.label_fs_ext -side left
	pack .advanced_options_window.f_options_udf.label_fs_udf -side left
	pack .advanced_options_window.f_opts_dvd_size.label_dvd_size -side left
	pack .advanced_options_window.f_oth_opts.label_oth_opts -side left
	pack .advanced_options_window.options_fs.joliet_ext .advanced_options_window.options_fs.rr_ext .advanced_options_window.options_fs.rra_ext .advanced_options_window.options_oth.overburn .advanced_options_window.options_oth.pad .advanced_options_window.options_oth.multisession .advanced_options_window.options_oth.monosession -side top -anchor w -padx {12 0}
	pack .advanced_options_window.f_dvd_size.single_layer .advanced_options_window.f_dvd_size.dual_layer -side left -anchor w -padx {12 0}
	#pack .advanced_options_window.f_dvd_size.b_save -side right -padx {0 12}
	pack .advanced_options_window.udf_radiobuttons.udf_ext_off .advanced_options_window.udf_radiobuttons.udf_ext .advanced_options_window.udf_radiobuttons.dvd_video_ext -side left -padx {24 0}
	#packing frames
	pack .advanced_options_window.f_fs_ext -fill x
	pack .advanced_options_window.options_fs -fill x
	pack .advanced_options_window.f_options_udf -fill x -padx {12 0}
	pack .advanced_options_window.udf_radiobuttons -fill x
	pack .advanced_options_window.f_opts_dvd_size -fill x
	pack .advanced_options_window.f_dvd_size -fill x
	pack .advanced_options_window.f_oth_opts -fill x
	pack .advanced_options_window.options_oth -fill x
	pack .advanced_options_window.b_close -side right -padx {0 12} -pady {0 6}
}
}
#source main TkDVD window
#    Copyright 2003 Regis Damongeot

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

. configure -background #f5f5f5

frame .f_label_first_step -background #c7d1d1
label .f_label_first_step.l_first_step -bg #c7d1d1 -text "Step 1: Select Files and Folders"

frame .f_first_step -background #f5f5f5
radiobutton .f_first_step.burn_dvd -activebackground #f5f5f5 -background #f5f5f5 -highlightbackground #f5f5f5 -text "Burn files and folders on a DVD" -command burn_dvd_proc -variable burn_type -value burn_dvd
.f_first_step.burn_dvd select

frame .f_first_step_b -background #f5f5f5
button .f_first_step_b.add -highlightbackground blue -text "Add Files..." -width 7 -command { add_file [tk_getOpenFile -multiple 1] }
button .f_first_step_b.add_d -highlightbackground blue -text "Add Directory..." -width 15 -command add_d
button .f_first_step_b.delete -highlightbackground blue -text "Delete File/Dir" -width 15 -command delete_files
button .f_first_step_b.clear -highlightbackground blue -text "Clear List" -width 7 -command { set file_list ""; refresh_total_file_size; refresh_cmd_line }
button .f_first_step_b.excluded_files -highlightbackground blue -width 15 -text "Excluded Files/Dir..." -command { excluded_file_window }

frame .f_upper_file_list -background #f5f5f5
label .f_upper_file_list.l_file_size -bg #f5f5f5 -text "Used space:"
entry .f_upper_file_list.show_file_size -relief flat -highlightbackground #f5f5f5 -highlightcolor #f5f5f5 -readonlybackground #f5f5f5 -state readonly -textvariable total_file_size_f -width 10
label .f_upper_file_list.l_space_left -bg #f5f5f5 -text "Free space:"
entry .f_upper_file_list.show_space_left -relief flat -highlightbackground #f5f5f5 -highlightcolor #f5f5f5 -readonlybackground #f5f5f5 -state readonly -textvariable space_left_f -width 10

frame .file_list -bg #f5f5f5
listbox .file_list.file_list -bg white -listvariable file_list -yscrollcommand { .file_list.scroll_bar set }
scrollbar .file_list.scroll_bar -command { .file_list.file_list yview }

frame .f_only_create_iso -bg #f5f5f5
checkbutton .f_only_create_iso.only_create_iso -activebackground #f5f5f5 -background #f5f5f5 -highlightbackground #f5f5f5 -text "Only create iso9660 image" -command { create_iso_proc } -variable v_create_iso -onvalue "yes" -offvalue "no"

frame .f_first_step_iso -background #f5f5f5
radiobutton .f_first_step_iso.b_burn_iso -activebackground #f5f5f5 -background #f5f5f5 -highlightbackground #f5f5f5 -text "Burn iso9660 image" -command { burn_iso_proc } -variable burn_type -value burn_iso
button  .f_first_step_iso.b_open_iso -highlightbackground blue -text "Open..." -state disabled -command choose_iso_file -width 7
entry .f_first_step_iso.iso_file -relief flat -highlightbackground blue -highlightcolor blue -readonlybackground #f5f5f5 -state readonly -textvariable iso_file -width 57

frame .f_label_second_step -background #c7d1d1
label .f_label_second_step.l_second_step -bg #c7d1d1 -text "Step 2: Customize Burning"

frame .f_burn_dev -background #f5f5f5
label .f_burn_dev.l_burn_device -bg #f5f5f5 -text "Burning device:"
entry .f_burn_dev.burn_device -relief flat -bg white -highlightbackground blue -highlightcolor blue -disabledbackground #f5f5f5 -state normal -textvariable burning_device
button .f_burn_dev.b_erase_dvd_rw -highlightbackground blue -width 15 -text "Erase DVD RW" -command { choose_format }

frame .f_vol_name -background #f5f5f5
label .f_vol_name.label_vname -bg #f5f5f5 -text "Volume name:"
entry .f_vol_name.volume_name -relief flat -bg white -highlightbackground blue -highlightcolor blue  -disabledbackground #f5f5f5 -state normal -textvariable volume_id_o
button .f_vol_name.b_advanced_options -highlightbackground blue -width 15 -text "Advanced Options..." -command { advanced_options_window }

frame .f_cmd_line -background #f5f5f5
label .f_cmd_line.label_vid -bg #f5f5f5 -text "Command:"
entry .f_cmd_line.cmd_line -relief flat -highlightbackground blue -highlightcolor blue -readonlybackground #f5f5f5 -state readonly -textvariable command_line -width 120

frame .f_burn -background #c7d1d1
button .f_burn.go_button -text "Burn" -highlightbackground red -command { refresh_cmd_line; launch "burn" } -width 7


pack .f_label_first_step.l_first_step -side left
pack .f_label_first_step -fill x

pack .f_first_step.burn_dvd -side left
pack .f_first_step -fill x

pack .f_first_step_b.add -side left -padx {0 10}
pack .f_first_step_b.add_d .f_first_step_b.delete .f_first_step_b.clear .f_first_step_b.excluded_files -side left -padx {10 10} -expand 0
pack .f_first_step_b.excluded_files -side right -padx {10 0}
pack .f_first_step_b -fill x -padx {50 15} -pady {7 3}

pack .f_upper_file_list.l_file_size .f_upper_file_list.show_file_size .f_upper_file_list.l_space_left .f_upper_file_list.show_space_left -side left
pack .f_upper_file_list -fill x -padx {50 0}

pack .file_list.scroll_bar -fill y -side right
pack .file_list.file_list -fill both -expand 1
pack .file_list -fill both -padx {50 15} -expand 1

pack .f_only_create_iso.only_create_iso -side left
pack .f_only_create_iso -fill x -padx {50 0} -pady {0 4}

pack .f_first_step_iso.b_burn_iso -side left
pack .f_first_step_iso.iso_file -side right -padx {12 0}
pack .f_first_step_iso.b_open_iso -side right
pack .f_first_step_iso -fill x -padx {0 15}

pack .f_label_second_step.l_second_step -side left
pack .f_label_second_step -fill x  -pady {12 12}

pack .f_burn_dev.l_burn_device -side left
pack .f_burn_dev.burn_device -side left -padx {4 0}
pack .f_burn_dev.b_erase_dvd_rw -side right  -padx {12 0}
pack .f_burn_dev -fill x -padx {20 15} -pady {0 10}

pack .f_vol_name.label_vname -side left
pack .f_vol_name.volume_name -side left -padx {13 0}
pack .f_vol_name.b_advanced_options -side right -padx {0 0}
pack .f_vol_name -fill x -padx {20 15} -pady {0 7}

pack .f_cmd_line.label_vid -side left
pack .f_cmd_line.cmd_line -side left -padx {34 0}
pack .f_cmd_line -fill x  -pady {0 10} -padx {20 15}

pack .f_burn.go_button -pady {2 2}
pack .f_burn -fill x


#Create frame for burn type
#frame .frame_burn_type -background #f5f5f5
#radiobutton .frame_burn_type.burn_dvd -activebackground #f5f5f5 -background #f5f5f5 -highlightbackground #f5f5f5 -text "Burn a DVD" -command burn_dvd_proc -variable burn_type -value burn_dvd
#.frame_burn_type.burn_dvd select
#radiobutton .frame_burn_type.create_iso -activebackground #f5f5f5 -background #f5f5f5 -highlightbackground #f5f5f5 -text "Only create iso9660 image" -command { create_iso_proc } -variable burn_type -value create_iso
#radiobutton .frame_burn_type.burn_iso -activebackground #f5f5f5 -background #f5f5f5 -highlightbackground #f5f5f5 -text "Burn iso9660 image" -command { burn_iso_proc } -variable burn_type -value burn_iso
#button  .frame_burn_type.open_iso -highlightbackground blue -text "Open..." -state disabled -command choose_iso_file -width 7
#entry .frame_burn_type.iso_file -relief flat -highlightbackground blue -highlightcolor blue -state readonly -textvariable iso_file -width 35
#pack .frame_burn_type.burn_dvd .frame_burn_type.create_iso .frame_burn_type.burn_iso .frame_burn_type.open_iso -side left
#pack .frame_burn_type.iso_file -side left -padx {6 0}
#pack .frame_burn_type -fill x

# create frame for command line and burning device
#frame .frame_command_line -background #f5f5f5
#label .frame_command_line.label_b_device -bg #f5f5f5 -text "Burning device:"
#entry .frame_command_line.b_device -relief flat -bg white -highlightbackground blue -highlightcolor blue -disabledbackground #f5f5f5 -state normal -textvariable burning_device
#entry .frame_command_line.cmd_line -relief flat -highlightbackground blue -highlightcolor blue -state readonly -textvariable command_line -width 50
#button .frame_command_line.go_button -text "Burn" -highlightbackground blue -command { refresh_cmd_line; Launch } -width 7
#pack .frame_command_line.label_b_device .frame_command_line.b_device .frame_command_line.cmd_line .frame_command_line.go_button -side left
#pack .frame_command_line.go_button -side left -padx {6 0}
#pack .frame_command_line -fill x

#frame for volume id, app id, etc
#frame .volume_id -background #f5f5f5
#label .volume_id.label_vid -bg #f5f5f5 -text "Volume ID:"
#entry .volume_id.volume_id -relief flat -bg white -highlightbackground blue -highlightcolor blue  -disabledbackground #f5f5f5 -state normal -textvariable volume_id_o
#button .volume_id.b_advanced_options -highlightbackground blue -width 15 -text "Advanced Options..." -command { advanced_options_window }
#pack .volume_id.label_vid .volume_id.volume_id -side left
#pack .volume_id.b_advanced_options -padx {6 0} -side left
#pack .volume_id -fill x

#create frame for file manipulations
#frame .files_manipulations -background #f5f5f5
#pack .files_manipulations  -fill x
#button .files_manipulations.add -highlightbackground blue -text "Add Files..." -width 7 -command { if { [catch { .file_selection.open cget -state }] } { create_file_list [FileOpen $selected_directory] } }
#button .files_manipulations.add_d -highlightbackground blue -text "Add Directory..." -width 15 -command add_d
#button .files_manipulations.delete -highlightbackground blue -text "Delete File/Dir" -width 15 -command delete_files
#button .files_manipulations.clear -highlightbackground blue -text "Clear List" -width 7 -command { set file_list ""; refresh_total_file_size; refresh_cmd_line }
#button .files_manipulations.excluded_files -highlightbackground blue -width 15 -text "Excluded Files/Dir..." -command { excluded_file_window }
#pack .files_manipulations.add .files_manipulations.add_d .files_manipulations.delete .files_manipulations.clear .files_manipulations.excluded_files -side left -pady {6 6}


#create frame containing label presenting the goal of the list and file size usage/free space
#frame .f_upper_file_list -background #f5f5f5
#label .f_upper_file_list.l_text_area -bg #f5f5f5 -text "Files and directories to be burn:"
#label .f_upper_file_list.label_file_size -bg #f5f5f5 -text "Total used space:"
#entry .f_upper_file_list.show_file_size -relief flat -highlightbackground blue -highlightcolor blue -state readonly -textvariable total_file_size_f -width 10
#label .f_upper_file_list.label_space_left -bg #f5f5f5 -text "Space left:"
#entry .f_upper_file_list.show_space_left -relief flat -highlightbackground blue -highlightcolor blue -state readonly -textvariable space_left_f -width 10
#pack .f_upper_file_list.l_text_area -fill x -side left
#reverse ordering with -side right
#pack .f_upper_file_list.show_space_left .f_upper_file_list.label_space_left  .f_upper_file_list.show_file_size .f_upper_file_list.label_file_size  -side right
#pack .f_upper_file_list -fill x

#create frame for file list
#frame .file_list
#listbox .file_list.list -bg #f5f5f5 -listvariable file_list -heigh 15 -yscrollcommand { .file_list.scroll_bar set }
#scrollbar .file_list.scroll_bar -command { .file_list.list yview }
#pack .file_list -fill both -expand false
#pack .file_list.scroll_bar -side right -fill y
#pack .file_list.list -fill x

#create frame and label presenting the goal of the 2nd text area
#frame .f_upper_output_msg -background #f5f5f5
#label .f_upper_output_msg.l_text_area -bg #f5f5f5 -text "growisofs/mkisofs output messages:"
#pack .f_upper_output_msg.l_text_area -side left
#pack .f_upper_output_msg -fill x

#create output frame
#frame .output
#text .output.log -heigh 10 -bg #f5f5f5 -relief ridge -setgrid true -yscrollcommand { .output.scroll_bar set }
#scrollbar .output.scroll_bar -command { .output.log yview }
#pack .output.scroll_bar -side right -fill y
#pack .output.log -side left -fill both -expand true
#pack .output -fill both -expand true


#load user default options
load_options

#beginning of the procedure part

proc file_list_w_modif_dir { file_list_to_modif } {
	#puts "$file_list_to_modif"
	set file_list_to_modif_f ""
	#set modified false
	for { set i 0 } { $i < [llength $file_list_to_modif]} { incr i } {
		if { [file isdirectory [lindex $file_list_to_modif $i]] } {
			set file_list_to_modif [lreplace $file_list_to_modif $i $i "[lindex [split [lindex $file_list_to_modif $i] /] end]/=[lindex $file_list_to_modif $i]"]
		} else {
		}
	}
	#if { $modified == true } { return [eval concat $file_list_to_modif] } else { return $file_list_to_modif }
	return $file_list_to_modif
}

#validatecommand must be after the called proc
.f_burn_dev.burn_device configure -validate focus -validatecommand refresh_cmd_line

proc choose_iso_file {} {
	global iso_file burn_type burning_device
	set iso_file_o ""
	if { $burn_type == "burn_iso" } {
		set iso_file_o [tk_getOpenFile -defaultextension .iso -title "Select ISO Image"]
		if { [llength $iso_file_o] > 1} {
			set iso_file [lindex $iso_file_o 0]
			for { set i 1} {$i < [llength $iso_file_o]} {incr i} {
				set iso_file "$iso_file\\ [lindex $iso_file_o $i]"
			}
		} else {
			set iso_file $iso_file_o
		}
	} else {
		set burning_device ""
		#set iso_file [tk_chooseDirectory -mustexist 0]
		set iso_file [tk_getSaveFile]
		set burning_device "-o"
		lappend burning_device $iso_file
	}
	refresh_cmd_line
}

proc check_volume_id {} {
	global volume_id volume_id_o
	set volume_id ""
	if { $volume_id_o == "" } {
		set volume_id ""
	} elseif { [llength $volume_id_o] > 1} {
			set volume_id [lindex $volume_id_o 0]
			for { set i 1} {$i < [llength $volume_id_o]} {incr i} {
				set volume_id "$volume_id\\ [lindex $volume_id_o $i]"
			}
			set volume_id "-V $volume_id"
		} else { set volume_id "-V $volume_id_o" }
}

proc add_file {files} {
	global file_list
	if { $files != "" } {
		#foreach needed for multiple files selection
		foreach i $files {
			lappend file_list $i
		}
		#puts "$file_list"
		refresh_total_file_size
		refresh_cmd_line
	} else {
	#puts "No file chosen"
	}
}

proc add_d {} {
	global file_list
	set temp [tk_chooseDirectory]
	set temp_f "[lindex $temp 0]"
	if { $temp != "" } {
		#for {set i 1} { $i < [llength $temp] } {incr i} {
		#	append temp_f "\\ [lindex $temp $i]"
		#}
		lappend file_list $temp
		#refresh command line entry after checking space used to check overburn condition
		refresh_total_file_size
		refresh_cmd_line
	}
}

proc delete_files {} {
	global file_list
	if { "[.file_list.file_list curselection]" == "" } {
	} else {
		set file_list [lreplace $file_list [.file_list.file_list curselection] [.file_list.file_list curselection]]
		#refresh command line entry after checking space used to check overburn condition
		refresh_total_file_size
		refresh_cmd_line
	}
}

proc launch {burn_type} {
	global input command_line burning_device
	#if output window not already created, we create it
	if { ! [winfo exists .output_window] } {
		toplevel .output_window -highlightthickness 1 -highlightcolor blue -background #f5f5f5
		wm title .output_window "growisofs/mkisofs output"
		frame .output_window.f_main
		text .output_window.f_main.log -heigh 10 -bg #f5f5f5 -relief ridge -setgrid true -yscrollcommand { .output_window.f_main.scroll_bar set }
		scrollbar .output_window.f_main.scroll_bar -command { .output_window.f_main.log yview }
		 button .output_window.b_close -highlightbackground blue -width 7 -text "Close" -command { destroy .output_window; refresh_cmd_line }
		
		pack .output_window.f_main.log -fill both -side left -expand 1
		pack .output_window.f_main.scroll_bar -fill y -side right
		pack .output_window.f_main -fill both -expand 1
		pack .output_window.b_close
	}
	.f_burn.go_button configure -state disabled
	if { $burn_type == "burn" } {
		if {[catch {open "|$command_line |& cat"} input]} {
			#one blank line to increase readability
			.output_window.f_main.log insert end "$command_line\n\n"
		} else {
			fileevent $input readable log_proc
			#one blank line to increase readability
			.output_window.f_main.log insert end "$command_line\n\n"
		}
	} else {
		# $burn_type= "" or "force" or "blank" => format
		if {[catch {open "|dvd+rw-format $burn_type $burning_device |& cat"} input]} {
			#one blank line to increase readability
			.output_window.f_main.log insert end "dvd+rw-format $burn_type $burning_device\n\n"
		} else {
			fileevent $input readable log_proc
			#one blank line to increase readability
			.output_window.f_main.log insert end "dvd+rw-format $burn_type $burning_device\n\n"
		}
	}
	after 4000 refresh_cmd_line
}

proc choose_format {} {
if { ! [winfo exists .format_window] } {
	
	toplevel .format_window -highlightthickness 1 -highlightcolor blue -background #f5f5f5
	wm title .format_window "Format DVD RW"
	
	frame .format_window.f_format_type -background #f5f5f5
	
	radiobutton .format_window.f_format_type.options_full_f -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "Full format (-blank=full)" -variable format_type -value "-blank"
	radiobutton .format_window.f_format_type.options_normal_f -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "Normal format (-force)" -variable format_type -value "-force"
	radiobutton .format_window.f_format_type.options_quick_f -bg #f5f5f5 -activebackground #f5f5f5 -highlightbackground #f5f5f5 -text "Quick format" -variable format_type -value ""
	
	button .format_window.b_erase -highlightbackground red -text "Erase" -command { launch $format_type; destroy .format_window}
	button .format_window.b_close -highlightbackground red -text "Close" -command { destroy .format_window}
	
	pack .format_window.f_format_type.options_quick_f -side left
	pack .format_window.f_format_type.options_normal_f -side left
	pack .format_window.f_format_type.options_full_f -side left
	pack .format_window.f_format_type -fill x -padx {0 12}
	pack .format_window.b_close .format_window.b_erase -fill x -side right -padx {0 12} -pady {6 6}
	
	.format_window.f_format_type.options_quick_f select
}
}

proc log_proc {} {
	global input
	if [eof $input] {
		catch { close $input }
		.output_window.f_main.log insert end "Writing finished"
		.output_window.f_main.log see end
	} else {
		gets $input line
		.output_window.f_main.log insert end $line\n
		.output_window.f_main.log see end
	}
}

proc burn_iso_proc {} {
	global burn_command t_session burning_device option_dvd_compat option_overburn v_create_iso option_dvd_compat
	set burn_command "growisofs"
	set t_session "-use-the-force-luke=tty -Z"
	set option_dvd_compat "-dvd-compat"
	set option_overburn ""
	load_options
	set v_create_iso "no"
	.f_first_step_iso.b_open_iso configure -state normal
	.f_only_create_iso.only_create_iso configure -state disabled
	.f_vol_name.label_vname configure -state disabled
	.f_vol_name.volume_name configure -state disabled
	.f_first_step_b.add configure -state disabled
	.f_first_step_b.add_d configure -state disabled
	.f_first_step_b.delete configure -state disabled
	.f_first_step_b.clear configure -state disabled
	.f_first_step_b.excluded_files configure -state disabled
	.file_list.file_list configure -state disabled
		if { [winfo exists .advanced_options_window] } {
		.advanced_options_window.options_oth.pad configure -state disabled
		.advanced_options_window.udf_radiobuttons.udf_ext configure -state disabled
		.advanced_options_window.udf_radiobuttons.udf_ext_off configure -state disabled
		.advanced_options_window.udf_radiobuttons.dvd_video_ext configure -state disabled
		.advanced_options_window.options_fs.rra_ext configure -state disabled
		.advanced_options_window.options_fs.rr_ext configure -state disabled
		.advanced_options_window.options_fs.joliet_ext configure -state disabled
		.advanced_options_window.options_oth.monosession  configure -state disabled
		.advanced_options_window.options_oth.overburn configure -state normal
		.advanced_options_window.options_oth.multisession configure -state normal
		#.advanced_options_window.f_dvd_size.single_layer configure -state normal
		#.advanced_options_window.f_dvd_size.dual_layer configure -state normal
		#.advanced_options_window.f_dvd_size.b_save configure -state normal
	}
	.f_upper_file_list.l_file_size configure -state disabled
	.f_upper_file_list.l_space_left configure -state disabled
	.f_burn_dev.l_burn_device configure -state normal
	.f_burn_dev.burn_device configure -state normal
	set volume_id ""
	set volume_id_o ""
	set option_joliet_ext ""
	set option_rr_ext ""
	set option_rra_ext ""
	set option_pad ""
	set option_dvd_compat ""
	refresh_cmd_line
}

proc burn_dvd_proc {} {
	global burn_command t_session burning_device option_dvd_compat option_overburn v_create_iso v_create_iso
	if {$v_create_iso == no}  {
	set burn_command "growisofs"
	set t_session "-use-the-force-luke=tty -Z"
	set option_dvd_compat "-dvd-compat"
	set option_overburn ""
	load_options
	.f_first_step_iso.b_open_iso configure -state disabled
	.f_only_create_iso.only_create_iso configure -state normal
	.f_vol_name.label_vname configure -state normal
	.f_vol_name.volume_name configure -state normal
	.f_first_step_b.add configure -state normal
	.f_first_step_b.add_d configure -state normal
	.f_first_step_b.delete configure -state normal
	.f_first_step_b.clear configure -state normal
	.f_first_step_b.excluded_files configure -state normal
	.file_list.file_list configure -state normal
	if { [winfo exists .advanced_options_window] } {
		.advanced_options_window.options_oth.pad configure -state normal
		.advanced_options_window.udf_radiobuttons.udf_ext configure -state normal
		.advanced_options_window.udf_radiobuttons.udf_ext_off configure -state normal
		.advanced_options_window.udf_radiobuttons.dvd_video_ext configure -state normal
		.advanced_options_window.options_fs.rra_ext configure -state normal
		.advanced_options_window.options_fs.rr_ext configure -state normal
		.advanced_options_window.options_fs.joliet_ext configure -state normal
		.advanced_options_window.options_oth.overburn configure -state normal
		.advanced_options_window.options_oth.multisession configure -state normal
		.advanced_options_window.options_oth.monosession configure -state normal
		#.advanced_options_window.f_dvd_size.single_layer configure -state normal
		#.advanced_options_window.f_dvd_size.dual_layer configure -state normal
		#.advanced_options_window.f_dvd_size.b_save configure -state normal
	}
	.f_upper_file_list.l_file_size configure -state normal
	.f_upper_file_list.l_space_left configure -state normal
	.f_burn_dev.l_burn_device configure -state normal
	.f_burn_dev.burn_device configure -state normal
	refresh_cmd_line
	}
}

proc create_iso_proc {} {
	global burn_command t_session burning_device option_dvd_compat option_overburn v_create_iso
	burn_dvd_proc
	if { $v_create_iso == "yes" } {
	if { [winfo exists .advanced_options_window] } {
		.advanced_options_window.options_oth.overburn configure -state disable
		.advanced_options_window.options_oth.multisession configure -state disabled
		.advanced_options_window.options_oth.monosession configure -state disabled
		#.advanced_options_window.f_dvd_size.single_layer configure -state disabled
		#.advanced_options_window.f_dvd_size.dual_layer configure -state disabled
		#.advanced_options_window.f_dvd_size.b_save configure -state disabled
	}
	.f_first_step_iso.b_open_iso configure -state normal
	.f_burn_dev.l_burn_device configure -state disabled
	.f_burn_dev.burn_device configure -state disabled
	set burn_command "mkisofs"
	set t_session ""
	set option_dvd_compat ""
	set option_overburn ""
	set burning_device ""
	refresh_cmd_line
	}
}

